# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['DependabotOrganizationSecretRepositoriesArgs', 'DependabotOrganizationSecretRepositories']

@pulumi.input_type
class DependabotOrganizationSecretRepositoriesArgs:
    def __init__(__self__, *,
                 secret_name: pulumi.Input[str],
                 selected_repository_ids: pulumi.Input[Sequence[pulumi.Input[int]]]):
        """
        The set of arguments for constructing a DependabotOrganizationSecretRepositories resource.
        :param pulumi.Input[str] secret_name: Name of the existing secret
        :param pulumi.Input[Sequence[pulumi.Input[int]]] selected_repository_ids: An array of repository ids that can access the organization secret.
        """
        pulumi.set(__self__, "secret_name", secret_name)
        pulumi.set(__self__, "selected_repository_ids", selected_repository_ids)

    @property
    @pulumi.getter(name="secretName")
    def secret_name(self) -> pulumi.Input[str]:
        """
        Name of the existing secret
        """
        return pulumi.get(self, "secret_name")

    @secret_name.setter
    def secret_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "secret_name", value)

    @property
    @pulumi.getter(name="selectedRepositoryIds")
    def selected_repository_ids(self) -> pulumi.Input[Sequence[pulumi.Input[int]]]:
        """
        An array of repository ids that can access the organization secret.
        """
        return pulumi.get(self, "selected_repository_ids")

    @selected_repository_ids.setter
    def selected_repository_ids(self, value: pulumi.Input[Sequence[pulumi.Input[int]]]):
        pulumi.set(self, "selected_repository_ids", value)


@pulumi.input_type
class _DependabotOrganizationSecretRepositoriesState:
    def __init__(__self__, *,
                 secret_name: Optional[pulumi.Input[str]] = None,
                 selected_repository_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None):
        """
        Input properties used for looking up and filtering DependabotOrganizationSecretRepositories resources.
        :param pulumi.Input[str] secret_name: Name of the existing secret
        :param pulumi.Input[Sequence[pulumi.Input[int]]] selected_repository_ids: An array of repository ids that can access the organization secret.
        """
        if secret_name is not None:
            pulumi.set(__self__, "secret_name", secret_name)
        if selected_repository_ids is not None:
            pulumi.set(__self__, "selected_repository_ids", selected_repository_ids)

    @property
    @pulumi.getter(name="secretName")
    def secret_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the existing secret
        """
        return pulumi.get(self, "secret_name")

    @secret_name.setter
    def secret_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_name", value)

    @property
    @pulumi.getter(name="selectedRepositoryIds")
    def selected_repository_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        An array of repository ids that can access the organization secret.
        """
        return pulumi.get(self, "selected_repository_ids")

    @selected_repository_ids.setter
    def selected_repository_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "selected_repository_ids", value)


class DependabotOrganizationSecretRepositories(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 secret_name: Optional[pulumi.Input[str]] = None,
                 selected_repository_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 __props__=None):
        """
        This resource allows you to manage the repository allow list for existing GitHub Dependabot secrets within your GitHub organization.
        You must have write access to an organization secret to use this resource.

        This resource is only applicable when `visibility` of the existing organization secret has been set to `selected`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        repo = github.get_repository(full_name="my-org/repo")
        example_secret = github.DependabotOrganizationSecret("example_secret",
            secret_name="example_secret_name",
            visibility="private",
            plaintext_value=some_secret_string)
        org_secret_repos = github.DependabotOrganizationSecretRepositories("org_secret_repos",
            secret_name=example_secret.secret_name,
            selected_repository_ids=[repo.repo_id])
        ```

        ## Import

        This resource can be imported using an ID made up of the secret name:

        ```sh
        $ pulumi import github:index/dependabotOrganizationSecretRepositories:DependabotOrganizationSecretRepositories test_secret_repos test_secret_name
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] secret_name: Name of the existing secret
        :param pulumi.Input[Sequence[pulumi.Input[int]]] selected_repository_ids: An array of repository ids that can access the organization secret.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DependabotOrganizationSecretRepositoriesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to manage the repository allow list for existing GitHub Dependabot secrets within your GitHub organization.
        You must have write access to an organization secret to use this resource.

        This resource is only applicable when `visibility` of the existing organization secret has been set to `selected`.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        repo = github.get_repository(full_name="my-org/repo")
        example_secret = github.DependabotOrganizationSecret("example_secret",
            secret_name="example_secret_name",
            visibility="private",
            plaintext_value=some_secret_string)
        org_secret_repos = github.DependabotOrganizationSecretRepositories("org_secret_repos",
            secret_name=example_secret.secret_name,
            selected_repository_ids=[repo.repo_id])
        ```

        ## Import

        This resource can be imported using an ID made up of the secret name:

        ```sh
        $ pulumi import github:index/dependabotOrganizationSecretRepositories:DependabotOrganizationSecretRepositories test_secret_repos test_secret_name
        ```

        :param str resource_name: The name of the resource.
        :param DependabotOrganizationSecretRepositoriesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DependabotOrganizationSecretRepositoriesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 secret_name: Optional[pulumi.Input[str]] = None,
                 selected_repository_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DependabotOrganizationSecretRepositoriesArgs.__new__(DependabotOrganizationSecretRepositoriesArgs)

            if secret_name is None and not opts.urn:
                raise TypeError("Missing required property 'secret_name'")
            __props__.__dict__["secret_name"] = secret_name
            if selected_repository_ids is None and not opts.urn:
                raise TypeError("Missing required property 'selected_repository_ids'")
            __props__.__dict__["selected_repository_ids"] = selected_repository_ids
        super(DependabotOrganizationSecretRepositories, __self__).__init__(
            'github:index/dependabotOrganizationSecretRepositories:DependabotOrganizationSecretRepositories',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            secret_name: Optional[pulumi.Input[str]] = None,
            selected_repository_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None) -> 'DependabotOrganizationSecretRepositories':
        """
        Get an existing DependabotOrganizationSecretRepositories resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] secret_name: Name of the existing secret
        :param pulumi.Input[Sequence[pulumi.Input[int]]] selected_repository_ids: An array of repository ids that can access the organization secret.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DependabotOrganizationSecretRepositoriesState.__new__(_DependabotOrganizationSecretRepositoriesState)

        __props__.__dict__["secret_name"] = secret_name
        __props__.__dict__["selected_repository_ids"] = selected_repository_ids
        return DependabotOrganizationSecretRepositories(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="secretName")
    def secret_name(self) -> pulumi.Output[str]:
        """
        Name of the existing secret
        """
        return pulumi.get(self, "secret_name")

    @property
    @pulumi.getter(name="selectedRepositoryIds")
    def selected_repository_ids(self) -> pulumi.Output[Sequence[int]]:
        """
        An array of repository ids that can access the organization secret.
        """
        return pulumi.get(self, "selected_repository_ids")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetUserExternalIdentityResult',
    'AwaitableGetUserExternalIdentityResult',
    'get_user_external_identity',
    'get_user_external_identity_output',
]

@pulumi.output_type
class GetUserExternalIdentityResult:
    """
    A collection of values returned by getUserExternalIdentity.
    """
    def __init__(__self__, id=None, login=None, saml_identity=None, scim_identity=None, username=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if login and not isinstance(login, str):
            raise TypeError("Expected argument 'login' to be a str")
        pulumi.set(__self__, "login", login)
        if saml_identity and not isinstance(saml_identity, dict):
            raise TypeError("Expected argument 'saml_identity' to be a dict")
        pulumi.set(__self__, "saml_identity", saml_identity)
        if scim_identity and not isinstance(scim_identity, dict):
            raise TypeError("Expected argument 'scim_identity' to be a dict")
        pulumi.set(__self__, "scim_identity", scim_identity)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def login(self) -> str:
        """
        The username of the GitHub user
        """
        return pulumi.get(self, "login")

    @property
    @pulumi.getter(name="samlIdentity")
    def saml_identity(self) -> Mapping[str, str]:
        """
        An Object containing the user's SAML data. This object will
        be empty if the user is not managed by SAML.
        """
        return pulumi.get(self, "saml_identity")

    @property
    @pulumi.getter(name="scimIdentity")
    def scim_identity(self) -> Mapping[str, str]:
        """
        An Object contining the user's SCIM data. This object will
        be empty if the user is not managed by SCIM.
        """
        return pulumi.get(self, "scim_identity")

    @property
    @pulumi.getter
    def username(self) -> str:
        """
        The member's SAML Username
        """
        return pulumi.get(self, "username")


class AwaitableGetUserExternalIdentityResult(GetUserExternalIdentityResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserExternalIdentityResult(
            id=self.id,
            login=self.login,
            saml_identity=self.saml_identity,
            scim_identity=self.scim_identity,
            username=self.username)


def get_user_external_identity(username: Optional[str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUserExternalIdentityResult:
    """
    Use this data source to retrieve a specific organization member's SAML or SCIM user
    attributes.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example_user = github.get_user_external_identity(username="example-user")
    ```


    :param str username: The username of the member to fetch external identity for.
    """
    __args__ = dict()
    __args__['username'] = username
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getUserExternalIdentity:getUserExternalIdentity', __args__, opts=opts, typ=GetUserExternalIdentityResult).value

    return AwaitableGetUserExternalIdentityResult(
        id=pulumi.get(__ret__, 'id'),
        login=pulumi.get(__ret__, 'login'),
        saml_identity=pulumi.get(__ret__, 'saml_identity'),
        scim_identity=pulumi.get(__ret__, 'scim_identity'),
        username=pulumi.get(__ret__, 'username'))


@_utilities.lift_output_func(get_user_external_identity)
def get_user_external_identity_output(username: Optional[pulumi.Input[str]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetUserExternalIdentityResult]:
    """
    Use this data source to retrieve a specific organization member's SAML or SCIM user
    attributes.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example_user = github.get_user_external_identity(username="example-user")
    ```


    :param str username: The username of the member to fetch external identity for.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['OrganizationProjectArgs', 'OrganizationProject']

@pulumi.input_type
class OrganizationProjectArgs:
    def __init__(__self__, *,
                 body: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a OrganizationProject resource.
        :param pulumi.Input[str] body: The body of the project.
        :param pulumi.Input[str] name: The name of the project.
        """
        if body is not None:
            pulumi.set(__self__, "body", body)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def body(self) -> Optional[pulumi.Input[str]]:
        """
        The body of the project.
        """
        return pulumi.get(self, "body")

    @body.setter
    def body(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "body", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _OrganizationProjectState:
    def __init__(__self__, *,
                 body: Optional[pulumi.Input[str]] = None,
                 etag: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 url: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering OrganizationProject resources.
        :param pulumi.Input[str] body: The body of the project.
        :param pulumi.Input[str] name: The name of the project.
        :param pulumi.Input[str] url: URL of the project
        """
        if body is not None:
            pulumi.set(__self__, "body", body)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def body(self) -> Optional[pulumi.Input[str]]:
        """
        The body of the project.
        """
        return pulumi.get(self, "body")

    @body.setter
    def body(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "body", value)

    @property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "etag", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the project.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[str]]:
        """
        URL of the project
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "url", value)


class OrganizationProject(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource allows you to create and manage projects for GitHub organization.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        project = github.OrganizationProject("project",
            name="A Organization Project",
            body="This is a organization project.")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] body: The body of the project.
        :param pulumi.Input[str] name: The name of the project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[OrganizationProjectArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and manage projects for GitHub organization.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        project = github.OrganizationProject("project",
            name="A Organization Project",
            body="This is a organization project.")
        ```

        :param str resource_name: The name of the resource.
        :param OrganizationProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OrganizationProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 body: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OrganizationProjectArgs.__new__(OrganizationProjectArgs)

            __props__.__dict__["body"] = body
            __props__.__dict__["name"] = name
            __props__.__dict__["etag"] = None
            __props__.__dict__["url"] = None
        super(OrganizationProject, __self__).__init__(
            'github:index/organizationProject:OrganizationProject',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            body: Optional[pulumi.Input[str]] = None,
            etag: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            url: Optional[pulumi.Input[str]] = None) -> 'OrganizationProject':
        """
        Get an existing OrganizationProject resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] body: The body of the project.
        :param pulumi.Input[str] name: The name of the project.
        :param pulumi.Input[str] url: URL of the project
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OrganizationProjectState.__new__(_OrganizationProjectState)

        __props__.__dict__["body"] = body
        __props__.__dict__["etag"] = etag
        __props__.__dict__["name"] = name
        __props__.__dict__["url"] = url
        return OrganizationProject(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def body(self) -> pulumi.Output[Optional[str]]:
        """
        The body of the project.
        """
        return pulumi.get(self, "body")

    @property
    @pulumi.getter
    def etag(self) -> pulumi.Output[str]:
        return pulumi.get(self, "etag")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the project.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[str]:
        """
        URL of the project
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetActionsOrganizationRegistrationTokenResult',
    'AwaitableGetActionsOrganizationRegistrationTokenResult',
    'get_actions_organization_registration_token',
    'get_actions_organization_registration_token_output',
]

@pulumi.output_type
class GetActionsOrganizationRegistrationTokenResult:
    """
    A collection of values returned by getActionsOrganizationRegistrationToken.
    """
    def __init__(__self__, expires_at=None, id=None, token=None):
        if expires_at and not isinstance(expires_at, int):
            raise TypeError("Expected argument 'expires_at' to be a int")
        pulumi.set(__self__, "expires_at", expires_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if token and not isinstance(token, str):
            raise TypeError("Expected argument 'token' to be a str")
        pulumi.set(__self__, "token", token)

    @property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> int:
        """
        The token expiration date.
        """
        return pulumi.get(self, "expires_at")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def token(self) -> str:
        """
        The token that has been retrieved.
        """
        return pulumi.get(self, "token")


class AwaitableGetActionsOrganizationRegistrationTokenResult(GetActionsOrganizationRegistrationTokenResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetActionsOrganizationRegistrationTokenResult(
            expires_at=self.expires_at,
            id=self.id,
            token=self.token)


def get_actions_organization_registration_token(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetActionsOrganizationRegistrationTokenResult:
    """
    Use this data source to retrieve a GitHub Actions organization registration token. This token can then be used to register a self-hosted runner.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_actions_organization_registration_token()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getActionsOrganizationRegistrationToken:getActionsOrganizationRegistrationToken', __args__, opts=opts, typ=GetActionsOrganizationRegistrationTokenResult).value

    return AwaitableGetActionsOrganizationRegistrationTokenResult(
        expires_at=pulumi.get(__ret__, 'expires_at'),
        id=pulumi.get(__ret__, 'id'),
        token=pulumi.get(__ret__, 'token'))


@_utilities.lift_output_func(get_actions_organization_registration_token)
def get_actions_organization_registration_token_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetActionsOrganizationRegistrationTokenResult]:
    """
    Use this data source to retrieve a GitHub Actions organization registration token. This token can then be used to register a self-hosted runner.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_actions_organization_registration_token()
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RepositoryCollaboratorsArgs', 'RepositoryCollaborators']

@pulumi.input_type
class RepositoryCollaboratorsArgs:
    def __init__(__self__, *,
                 repository: pulumi.Input[str],
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsTeamArgs']]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsUserArgs']]]] = None):
        """
        The set of arguments for constructing a RepositoryCollaborators resource.
        :param pulumi.Input[str] repository: The GitHub repository
        :param pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsTeamArgs']]] teams: List of teams
        :param pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsUserArgs']]] users: List of users
        """
        pulumi.set(__self__, "repository", repository)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Input[str]:
        """
        The GitHub repository
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: pulumi.Input[str]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsTeamArgs']]]]:
        """
        List of teams
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsTeamArgs']]]]):
        pulumi.set(self, "teams", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsUserArgs']]]]:
        """
        List of users
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsUserArgs']]]]):
        pulumi.set(self, "users", value)


@pulumi.input_type
class _RepositoryCollaboratorsState:
    def __init__(__self__, *,
                 invitation_ids: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsTeamArgs']]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsUserArgs']]]] = None):
        """
        Input properties used for looking up and filtering RepositoryCollaborators resources.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] invitation_ids: Map of usernames to invitation ID for any users added as part of creation of this resource to 
               be used in `UserInvitationAccepter`.
        :param pulumi.Input[str] repository: The GitHub repository
        :param pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsTeamArgs']]] teams: List of teams
        :param pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsUserArgs']]] users: List of users
        """
        if invitation_ids is not None:
            pulumi.set(__self__, "invitation_ids", invitation_ids)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if teams is not None:
            pulumi.set(__self__, "teams", teams)
        if users is not None:
            pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter(name="invitationIds")
    def invitation_ids(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Map of usernames to invitation ID for any users added as part of creation of this resource to 
        be used in `UserInvitationAccepter`.
        """
        return pulumi.get(self, "invitation_ids")

    @invitation_ids.setter
    def invitation_ids(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "invitation_ids", value)

    @property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[str]]:
        """
        The GitHub repository
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter
    def teams(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsTeamArgs']]]]:
        """
        List of teams
        """
        return pulumi.get(self, "teams")

    @teams.setter
    def teams(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsTeamArgs']]]]):
        pulumi.set(self, "teams", value)

    @property
    @pulumi.getter
    def users(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsUserArgs']]]]:
        """
        List of users
        """
        return pulumi.get(self, "users")

    @users.setter
    def users(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryCollaboratorsUserArgs']]]]):
        pulumi.set(self, "users", value)


class RepositoryCollaborators(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsTeamArgs', 'RepositoryCollaboratorsTeamArgsDict']]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsUserArgs', 'RepositoryCollaboratorsUserArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides a GitHub repository collaborators resource.

        > Note: RepositoryCollaborators cannot be used in conjunction with RepositoryCollaborator and
        TeamRepository or they will fight over what your policy should be.

        This resource allows you to manage all collaborators for repositories in your
        organization or personal account. For organization repositories, collaborators can
        have explicit (and differing levels of) read, write, or administrator access to
        specific repositories, without giving the user full organization membership.
        For personal repositories, collaborators can only be granted write
        (implicitly includes read) permission.

        When applied, an invitation will be sent to the user to become a collaborators
        on a repository. When destroyed, either the invitation will be cancelled or the
        collaborators will be removed from the repository.

        This resource is authoritative. For adding a collaborator to a repo in a non-authoritative manner, use
        RepositoryCollaborator instead.

        Further documentation on GitHub collaborators:

        - [Adding outside collaborators to your personal repositories](https://help.github.com/en/github/setting-up-and-managing-your-github-user-account/managing-access-to-your-personal-repositories)
        - [Adding outside collaborators to repositories in your organization](https://help.github.com/articles/adding-outside-collaborators-to-repositories-in-your-organization/)
        - [Converting an organization member to an outside collaborators](https://help.github.com/articles/converting-an-organization-member-to-an-outside-collaborator/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        # Add collaborators to a repository
        some_team = github.Team("some_team",
            name="SomeTeam",
            description="Some cool team")
        some_repo = github.Repository("some_repo", name="some-repo")
        some_repo_collaborators = github.RepositoryCollaborators("some_repo_collaborators",
            repository=some_repo.name,
            users=[{
                "permission": "admin",
                "username": "SomeUser",
            }],
            teams=[{
                "permission": "pull",
                "team_id": some_team.slug,
            }])
        ```

        ## Import

        GitHub Repository Collaborators can be imported using the name `name`, e.g.

        ```sh
        $ pulumi import github:index/repositoryCollaborators:RepositoryCollaborators collaborators terraform
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] repository: The GitHub repository
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsTeamArgs', 'RepositoryCollaboratorsTeamArgsDict']]]] teams: List of teams
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsUserArgs', 'RepositoryCollaboratorsUserArgsDict']]]] users: List of users
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepositoryCollaboratorsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a GitHub repository collaborators resource.

        > Note: RepositoryCollaborators cannot be used in conjunction with RepositoryCollaborator and
        TeamRepository or they will fight over what your policy should be.

        This resource allows you to manage all collaborators for repositories in your
        organization or personal account. For organization repositories, collaborators can
        have explicit (and differing levels of) read, write, or administrator access to
        specific repositories, without giving the user full organization membership.
        For personal repositories, collaborators can only be granted write
        (implicitly includes read) permission.

        When applied, an invitation will be sent to the user to become a collaborators
        on a repository. When destroyed, either the invitation will be cancelled or the
        collaborators will be removed from the repository.

        This resource is authoritative. For adding a collaborator to a repo in a non-authoritative manner, use
        RepositoryCollaborator instead.

        Further documentation on GitHub collaborators:

        - [Adding outside collaborators to your personal repositories](https://help.github.com/en/github/setting-up-and-managing-your-github-user-account/managing-access-to-your-personal-repositories)
        - [Adding outside collaborators to repositories in your organization](https://help.github.com/articles/adding-outside-collaborators-to-repositories-in-your-organization/)
        - [Converting an organization member to an outside collaborators](https://help.github.com/articles/converting-an-organization-member-to-an-outside-collaborator/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        # Add collaborators to a repository
        some_team = github.Team("some_team",
            name="SomeTeam",
            description="Some cool team")
        some_repo = github.Repository("some_repo", name="some-repo")
        some_repo_collaborators = github.RepositoryCollaborators("some_repo_collaborators",
            repository=some_repo.name,
            users=[{
                "permission": "admin",
                "username": "SomeUser",
            }],
            teams=[{
                "permission": "pull",
                "team_id": some_team.slug,
            }])
        ```

        ## Import

        GitHub Repository Collaborators can be imported using the name `name`, e.g.

        ```sh
        $ pulumi import github:index/repositoryCollaborators:RepositoryCollaborators collaborators terraform
        ```

        :param str resource_name: The name of the resource.
        :param RepositoryCollaboratorsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepositoryCollaboratorsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 teams: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsTeamArgs', 'RepositoryCollaboratorsTeamArgsDict']]]]] = None,
                 users: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsUserArgs', 'RepositoryCollaboratorsUserArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepositoryCollaboratorsArgs.__new__(RepositoryCollaboratorsArgs)

            if repository is None and not opts.urn:
                raise TypeError("Missing required property 'repository'")
            __props__.__dict__["repository"] = repository
            __props__.__dict__["teams"] = teams
            __props__.__dict__["users"] = users
            __props__.__dict__["invitation_ids"] = None
        super(RepositoryCollaborators, __self__).__init__(
            'github:index/repositoryCollaborators:RepositoryCollaborators',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            invitation_ids: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            repository: Optional[pulumi.Input[str]] = None,
            teams: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsTeamArgs', 'RepositoryCollaboratorsTeamArgsDict']]]]] = None,
            users: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsUserArgs', 'RepositoryCollaboratorsUserArgsDict']]]]] = None) -> 'RepositoryCollaborators':
        """
        Get an existing RepositoryCollaborators resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] invitation_ids: Map of usernames to invitation ID for any users added as part of creation of this resource to 
               be used in `UserInvitationAccepter`.
        :param pulumi.Input[str] repository: The GitHub repository
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsTeamArgs', 'RepositoryCollaboratorsTeamArgsDict']]]] teams: List of teams
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepositoryCollaboratorsUserArgs', 'RepositoryCollaboratorsUserArgsDict']]]] users: List of users
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepositoryCollaboratorsState.__new__(_RepositoryCollaboratorsState)

        __props__.__dict__["invitation_ids"] = invitation_ids
        __props__.__dict__["repository"] = repository
        __props__.__dict__["teams"] = teams
        __props__.__dict__["users"] = users
        return RepositoryCollaborators(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="invitationIds")
    def invitation_ids(self) -> pulumi.Output[Mapping[str, str]]:
        """
        Map of usernames to invitation ID for any users added as part of creation of this resource to 
        be used in `UserInvitationAccepter`.
        """
        return pulumi.get(self, "invitation_ids")

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Output[str]:
        """
        The GitHub repository
        """
        return pulumi.get(self, "repository")

    @property
    @pulumi.getter
    def teams(self) -> pulumi.Output[Optional[Sequence['outputs.RepositoryCollaboratorsTeam']]]:
        """
        List of teams
        """
        return pulumi.get(self, "teams")

    @property
    @pulumi.getter
    def users(self) -> pulumi.Output[Optional[Sequence['outputs.RepositoryCollaboratorsUser']]]:
        """
        List of users
        """
        return pulumi.get(self, "users")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult',
    'AwaitableGetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult',
    'get_actions_organization_oidc_subject_claim_customization_template',
    'get_actions_organization_oidc_subject_claim_customization_template_output',
]

@pulumi.output_type
class GetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult:
    """
    A collection of values returned by getActionsOrganizationOidcSubjectClaimCustomizationTemplate.
    """
    def __init__(__self__, id=None, include_claim_keys=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if include_claim_keys and not isinstance(include_claim_keys, list):
            raise TypeError("Expected argument 'include_claim_keys' to be a list")
        pulumi.set(__self__, "include_claim_keys", include_claim_keys)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="includeClaimKeys")
    def include_claim_keys(self) -> Sequence[str]:
        """
        The list of OpenID Connect claim keys.
        """
        return pulumi.get(self, "include_claim_keys")


class AwaitableGetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult(GetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult(
            id=self.id,
            include_claim_keys=self.include_claim_keys)


def get_actions_organization_oidc_subject_claim_customization_template(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult:
    """
    Use this data source to retrieve the OpenID Connect subject claim customization template for an organization

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_actions_organization_oidc_subject_claim_customization_template()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getActionsOrganizationOidcSubjectClaimCustomizationTemplate:getActionsOrganizationOidcSubjectClaimCustomizationTemplate', __args__, opts=opts, typ=GetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult).value

    return AwaitableGetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult(
        id=pulumi.get(__ret__, 'id'),
        include_claim_keys=pulumi.get(__ret__, 'include_claim_keys'))


@_utilities.lift_output_func(get_actions_organization_oidc_subject_claim_customization_template)
def get_actions_organization_oidc_subject_claim_customization_template_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetActionsOrganizationOidcSubjectClaimCustomizationTemplateResult]:
    """
    Use this data source to retrieve the OpenID Connect subject claim customization template for an organization

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_actions_organization_oidc_subject_claim_customization_template()
    ```
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ActionsEnvironmentVariableArgs', 'ActionsEnvironmentVariable']

@pulumi.input_type
class ActionsEnvironmentVariableArgs:
    def __init__(__self__, *,
                 environment: pulumi.Input[str],
                 repository: pulumi.Input[str],
                 value: pulumi.Input[str],
                 variable_name: pulumi.Input[str]):
        """
        The set of arguments for constructing a ActionsEnvironmentVariable resource.
        :param pulumi.Input[str] environment: Name of the environment.
        :param pulumi.Input[str] repository: Name of the repository.
        :param pulumi.Input[str] value: Value of the variable
        :param pulumi.Input[str] variable_name: Name of the variable.
        """
        pulumi.set(__self__, "environment", environment)
        pulumi.set(__self__, "repository", repository)
        pulumi.set(__self__, "value", value)
        pulumi.set(__self__, "variable_name", variable_name)

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Input[str]:
        """
        Name of the environment.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input[str]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Input[str]:
        """
        Name of the repository.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: pulumi.Input[str]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[str]:
        """
        Value of the variable
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[str]):
        pulumi.set(self, "value", value)

    @property
    @pulumi.getter(name="variableName")
    def variable_name(self) -> pulumi.Input[str]:
        """
        Name of the variable.
        """
        return pulumi.get(self, "variable_name")

    @variable_name.setter
    def variable_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "variable_name", value)


@pulumi.input_type
class _ActionsEnvironmentVariableState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[str]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 variable_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ActionsEnvironmentVariable resources.
        :param pulumi.Input[str] created_at: Date of actions_environment_secret creation.
        :param pulumi.Input[str] environment: Name of the environment.
        :param pulumi.Input[str] repository: Name of the repository.
        :param pulumi.Input[str] updated_at: Date of actions_environment_secret update.
        :param pulumi.Input[str] value: Value of the variable
        :param pulumi.Input[str] variable_name: Name of the variable.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if variable_name is not None:
            pulumi.set(__self__, "variable_name", variable_name)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date of actions_environment_secret creation.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the environment.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the repository.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date of actions_environment_secret update.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        Value of the variable
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)

    @property
    @pulumi.getter(name="variableName")
    def variable_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the variable.
        """
        return pulumi.get(self, "variable_name")

    @variable_name.setter
    def variable_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "variable_name", value)


class ActionsEnvironmentVariable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 variable_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource allows you to create and manage GitHub Actions variables within your GitHub repository environments.
        You must have write access to a repository to use this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        example_variable = github.ActionsEnvironmentVariable("example_variable",
            environment="example_environment",
            variable_name="example_variable_name",
            value="example_variable_value")
        ```

        ```python
        import pulumi
        import pulumi_github as github

        repo = github.get_repository(full_name="my-org/repo")
        repo_environment = github.RepositoryEnvironment("repo_environment",
            repository=repo.name,
            environment="example_environment")
        example_variable = github.ActionsEnvironmentVariable("example_variable",
            repository=repo.name,
            environment=repo_environment.environment,
            variable_name="example_variable_name",
            value="example_variable_value")
        ```

        ## Import

        This resource can be imported using an ID made up of the repository name, environment name, and variable name:

        ```sh
        $ pulumi import github:index/actionsEnvironmentVariable:ActionsEnvironmentVariable test_variable myrepo:myenv:myvariable
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] environment: Name of the environment.
        :param pulumi.Input[str] repository: Name of the repository.
        :param pulumi.Input[str] value: Value of the variable
        :param pulumi.Input[str] variable_name: Name of the variable.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ActionsEnvironmentVariableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and manage GitHub Actions variables within your GitHub repository environments.
        You must have write access to a repository to use this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        example_variable = github.ActionsEnvironmentVariable("example_variable",
            environment="example_environment",
            variable_name="example_variable_name",
            value="example_variable_value")
        ```

        ```python
        import pulumi
        import pulumi_github as github

        repo = github.get_repository(full_name="my-org/repo")
        repo_environment = github.RepositoryEnvironment("repo_environment",
            repository=repo.name,
            environment="example_environment")
        example_variable = github.ActionsEnvironmentVariable("example_variable",
            repository=repo.name,
            environment=repo_environment.environment,
            variable_name="example_variable_name",
            value="example_variable_value")
        ```

        ## Import

        This resource can be imported using an ID made up of the repository name, environment name, and variable name:

        ```sh
        $ pulumi import github:index/actionsEnvironmentVariable:ActionsEnvironmentVariable test_variable myrepo:myenv:myvariable
        ```

        :param str resource_name: The name of the resource.
        :param ActionsEnvironmentVariableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ActionsEnvironmentVariableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 variable_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ActionsEnvironmentVariableArgs.__new__(ActionsEnvironmentVariableArgs)

            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            if repository is None and not opts.urn:
                raise TypeError("Missing required property 'repository'")
            __props__.__dict__["repository"] = repository
            if value is None and not opts.urn:
                raise TypeError("Missing required property 'value'")
            __props__.__dict__["value"] = value
            if variable_name is None and not opts.urn:
                raise TypeError("Missing required property 'variable_name'")
            __props__.__dict__["variable_name"] = variable_name
            __props__.__dict__["created_at"] = None
            __props__.__dict__["updated_at"] = None
        super(ActionsEnvironmentVariable, __self__).__init__(
            'github:index/actionsEnvironmentVariable:ActionsEnvironmentVariable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            environment: Optional[pulumi.Input[str]] = None,
            repository: Optional[pulumi.Input[str]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            value: Optional[pulumi.Input[str]] = None,
            variable_name: Optional[pulumi.Input[str]] = None) -> 'ActionsEnvironmentVariable':
        """
        Get an existing ActionsEnvironmentVariable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] created_at: Date of actions_environment_secret creation.
        :param pulumi.Input[str] environment: Name of the environment.
        :param pulumi.Input[str] repository: Name of the repository.
        :param pulumi.Input[str] updated_at: Date of actions_environment_secret update.
        :param pulumi.Input[str] value: Value of the variable
        :param pulumi.Input[str] variable_name: Name of the variable.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ActionsEnvironmentVariableState.__new__(_ActionsEnvironmentVariableState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["environment"] = environment
        __props__.__dict__["repository"] = repository
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["value"] = value
        __props__.__dict__["variable_name"] = variable_name
        return ActionsEnvironmentVariable(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date of actions_environment_secret creation.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Output[str]:
        """
        Name of the environment.
        """
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Output[str]:
        """
        Name of the repository.
        """
        return pulumi.get(self, "repository")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date of actions_environment_secret update.
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def value(self) -> pulumi.Output[str]:
        """
        Value of the variable
        """
        return pulumi.get(self, "value")

    @property
    @pulumi.getter(name="variableName")
    def variable_name(self) -> pulumi.Output[str]:
        """
        Name of the variable.
        """
        return pulumi.get(self, "variable_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from . import _utilities
import typing
# Export this package's modules as members:
from .actions_environment_secret import *
from .actions_environment_variable import *
from .actions_organization_oidc_subject_claim_customization_template import *
from .actions_organization_permissions import *
from .actions_organization_secret import *
from .actions_organization_secret_repositories import *
from .actions_organization_variable import *
from .actions_repository_access_level import *
from .actions_repository_oidc_subject_claim_customization_template import *
from .actions_repository_permissions import *
from .actions_runner_group import *
from .actions_secret import *
from .actions_variable import *
from .app_installation_repositories import *
from .app_installation_repository import *
from .branch import *
from .branch_default import *
from .branch_protection import *
from .branch_protection_v3 import *
from .codespaces_organization_secret import *
from .codespaces_organization_secret_repositories import *
from .codespaces_secret import *
from .codespaces_user_secret import *
from .dependabot_organization_secret import *
from .dependabot_organization_secret_repositories import *
from .dependabot_secret import *
from .emu_group_mapping import *
from .enterprise_actions_permissions import *
from .enterprise_actions_runner_group import *
from .enterprise_organization import *
from .get_actions_environment_secrets import *
from .get_actions_environment_variables import *
from .get_actions_organization_oidc_subject_claim_customization_template import *
from .get_actions_organization_public_key import *
from .get_actions_organization_registration_token import *
from .get_actions_organization_secrets import *
from .get_actions_organization_variables import *
from .get_actions_public_key import *
from .get_actions_registration_token import *
from .get_actions_repository_oidc_subject_claim_customization_template import *
from .get_actions_secrets import *
from .get_actions_variables import *
from .get_app_token import *
from .get_branch import *
from .get_branch_protection_rules import *
from .get_codespaces_organization_public_key import *
from .get_codespaces_organization_secrets import *
from .get_codespaces_public_key import *
from .get_codespaces_secrets import *
from .get_codespaces_user_public_key import *
from .get_codespaces_user_secrets import *
from .get_collaborators import *
from .get_dependabot_organization_public_key import *
from .get_dependabot_organization_secrets import *
from .get_dependabot_public_key import *
from .get_dependabot_secrets import *
from .get_enterprise import *
from .get_external_groups import *
from .get_github_app import *
from .get_ip_ranges import *
from .get_issue_labels import *
from .get_membership import *
from .get_organization import *
from .get_organization_custom_role import *
from .get_organization_external_identities import *
from .get_organization_ip_allow_list import *
from .get_organization_team_sync_groups import *
from .get_organization_teams import *
from .get_organization_webhooks import *
from .get_ref import *
from .get_release import *
from .get_repositories import *
from .get_repository import *
from .get_repository_autolink_references import *
from .get_repository_branches import *
from .get_repository_deploy_keys import *
from .get_repository_deployment_branch_policies import *
from .get_repository_environments import *
from .get_repository_file import *
from .get_repository_milestone import *
from .get_repository_pull_request import *
from .get_repository_pull_requests import *
from .get_repository_teams import *
from .get_repository_webhooks import *
from .get_rest_api import *
from .get_ssh_keys import *
from .get_team import *
from .get_tree import *
from .get_user import *
from .get_user_external_identity import *
from .get_users import *
from .issue import *
from .issue_label import *
from .issue_labels import *
from .membership import *
from .organization_block import *
from .organization_custom_role import *
from .organization_project import *
from .organization_ruleset import *
from .organization_security_manager import *
from .organization_settings import *
from .organization_webhook import *
from .project_card import *
from .project_column import *
from .provider import *
from .release import *
from .repository import *
from .repository_autolink_reference import *
from .repository_collaborator import *
from .repository_collaborators import *
from .repository_dependabot_security_updates import *
from .repository_deploy_key import *
from .repository_deployment_branch_policy import *
from .repository_environment import *
from .repository_environment_deployment_policy import *
from .repository_file import *
from .repository_milestone import *
from .repository_project import *
from .repository_pull_request import *
from .repository_ruleset import *
from .repository_tag_protection import *
from .repository_topics import *
from .repository_webhook import *
from .team import *
from .team_members import *
from .team_membership import *
from .team_repository import *
from .team_settings import *
from .team_sync_group_mapping import *
from .user_gpg_key import *
from .user_invitation_accepter import *
from .user_ssh_key import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_github.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumi_github.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "github",
  "mod": "index/actionsEnvironmentSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsEnvironmentSecret:ActionsEnvironmentSecret": "ActionsEnvironmentSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsEnvironmentVariable",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsEnvironmentVariable:ActionsEnvironmentVariable": "ActionsEnvironmentVariable"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsOrganizationOidcSubjectClaimCustomizationTemplate",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsOrganizationOidcSubjectClaimCustomizationTemplate:ActionsOrganizationOidcSubjectClaimCustomizationTemplate": "ActionsOrganizationOidcSubjectClaimCustomizationTemplate"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsOrganizationPermissions",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsOrganizationPermissions:ActionsOrganizationPermissions": "ActionsOrganizationPermissions"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsOrganizationSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsOrganizationSecret:ActionsOrganizationSecret": "ActionsOrganizationSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsOrganizationSecretRepositories",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsOrganizationSecretRepositories:ActionsOrganizationSecretRepositories": "ActionsOrganizationSecretRepositories"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsOrganizationVariable",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsOrganizationVariable:ActionsOrganizationVariable": "ActionsOrganizationVariable"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsRepositoryAccessLevel",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsRepositoryAccessLevel:ActionsRepositoryAccessLevel": "ActionsRepositoryAccessLevel"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsRepositoryOidcSubjectClaimCustomizationTemplate",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsRepositoryOidcSubjectClaimCustomizationTemplate:ActionsRepositoryOidcSubjectClaimCustomizationTemplate": "ActionsRepositoryOidcSubjectClaimCustomizationTemplate"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsRepositoryPermissions",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsRepositoryPermissions:ActionsRepositoryPermissions": "ActionsRepositoryPermissions"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsRunnerGroup",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsRunnerGroup:ActionsRunnerGroup": "ActionsRunnerGroup"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsSecret:ActionsSecret": "ActionsSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/actionsVariable",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/actionsVariable:ActionsVariable": "ActionsVariable"
  }
 },
 {
  "pkg": "github",
  "mod": "index/appInstallationRepositories",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/appInstallationRepositories:AppInstallationRepositories": "AppInstallationRepositories"
  }
 },
 {
  "pkg": "github",
  "mod": "index/appInstallationRepository",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/appInstallationRepository:AppInstallationRepository": "AppInstallationRepository"
  }
 },
 {
  "pkg": "github",
  "mod": "index/branch",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/branch:Branch": "Branch"
  }
 },
 {
  "pkg": "github",
  "mod": "index/branchDefault",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/branchDefault:BranchDefault": "BranchDefault"
  }
 },
 {
  "pkg": "github",
  "mod": "index/branchProtection",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/branchProtection:BranchProtection": "BranchProtection"
  }
 },
 {
  "pkg": "github",
  "mod": "index/branchProtectionV3",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/branchProtectionV3:BranchProtectionV3": "BranchProtectionV3"
  }
 },
 {
  "pkg": "github",
  "mod": "index/codespacesOrganizationSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/codespacesOrganizationSecret:CodespacesOrganizationSecret": "CodespacesOrganizationSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/codespacesOrganizationSecretRepositories",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/codespacesOrganizationSecretRepositories:CodespacesOrganizationSecretRepositories": "CodespacesOrganizationSecretRepositories"
  }
 },
 {
  "pkg": "github",
  "mod": "index/codespacesSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/codespacesSecret:CodespacesSecret": "CodespacesSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/codespacesUserSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/codespacesUserSecret:CodespacesUserSecret": "CodespacesUserSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/dependabotOrganizationSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/dependabotOrganizationSecret:DependabotOrganizationSecret": "DependabotOrganizationSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/dependabotOrganizationSecretRepositories",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/dependabotOrganizationSecretRepositories:DependabotOrganizationSecretRepositories": "DependabotOrganizationSecretRepositories"
  }
 },
 {
  "pkg": "github",
  "mod": "index/dependabotSecret",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/dependabotSecret:DependabotSecret": "DependabotSecret"
  }
 },
 {
  "pkg": "github",
  "mod": "index/emuGroupMapping",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/emuGroupMapping:EmuGroupMapping": "EmuGroupMapping"
  }
 },
 {
  "pkg": "github",
  "mod": "index/enterpriseActionsPermissions",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/enterpriseActionsPermissions:EnterpriseActionsPermissions": "EnterpriseActionsPermissions"
  }
 },
 {
  "pkg": "github",
  "mod": "index/enterpriseActionsRunnerGroup",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/enterpriseActionsRunnerGroup:EnterpriseActionsRunnerGroup": "EnterpriseActionsRunnerGroup"
  }
 },
 {
  "pkg": "github",
  "mod": "index/enterpriseOrganization",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/enterpriseOrganization:EnterpriseOrganization": "EnterpriseOrganization"
  }
 },
 {
  "pkg": "github",
  "mod": "index/issue",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/issue:Issue": "Issue"
  }
 },
 {
  "pkg": "github",
  "mod": "index/issueLabel",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/issueLabel:IssueLabel": "IssueLabel"
  }
 },
 {
  "pkg": "github",
  "mod": "index/issueLabels",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/issueLabels:IssueLabels": "IssueLabels"
  }
 },
 {
  "pkg": "github",
  "mod": "index/membership",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/membership:Membership": "Membership"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationBlock",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationBlock:OrganizationBlock": "OrganizationBlock"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationCustomRole",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationCustomRole:OrganizationCustomRole": "OrganizationCustomRole"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationProject",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationProject:OrganizationProject": "OrganizationProject"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationRuleset",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationRuleset:OrganizationRuleset": "OrganizationRuleset"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationSecurityManager",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationSecurityManager:OrganizationSecurityManager": "OrganizationSecurityManager"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationSettings",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationSettings:OrganizationSettings": "OrganizationSettings"
  }
 },
 {
  "pkg": "github",
  "mod": "index/organizationWebhook",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/organizationWebhook:OrganizationWebhook": "OrganizationWebhook"
  }
 },
 {
  "pkg": "github",
  "mod": "index/projectCard",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/projectCard:ProjectCard": "ProjectCard"
  }
 },
 {
  "pkg": "github",
  "mod": "index/projectColumn",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/projectColumn:ProjectColumn": "ProjectColumn"
  }
 },
 {
  "pkg": "github",
  "mod": "index/release",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/release:Release": "Release"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repository",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryAutolinkReference",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryAutolinkReference:RepositoryAutolinkReference": "RepositoryAutolinkReference"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryCollaborator",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryCollaborator:RepositoryCollaborator": "RepositoryCollaborator"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryCollaborators",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryCollaborators:RepositoryCollaborators": "RepositoryCollaborators"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryDependabotSecurityUpdates",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryDependabotSecurityUpdates:RepositoryDependabotSecurityUpdates": "RepositoryDependabotSecurityUpdates"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryDeployKey",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryDeployKey:RepositoryDeployKey": "RepositoryDeployKey"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryDeploymentBranchPolicy",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryDeploymentBranchPolicy:RepositoryDeploymentBranchPolicy": "RepositoryDeploymentBranchPolicy"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryEnvironment",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryEnvironment:RepositoryEnvironment": "RepositoryEnvironment"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryEnvironmentDeploymentPolicy",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryEnvironmentDeploymentPolicy:RepositoryEnvironmentDeploymentPolicy": "RepositoryEnvironmentDeploymentPolicy"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryFile",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryFile:RepositoryFile": "RepositoryFile"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryMilestone",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryMilestone:RepositoryMilestone": "RepositoryMilestone"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryProject",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryProject:RepositoryProject": "RepositoryProject"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryPullRequest",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryPullRequest:RepositoryPullRequest": "RepositoryPullRequest"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryRuleset",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryRuleset:RepositoryRuleset": "RepositoryRuleset"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryTagProtection",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryTagProtection:RepositoryTagProtection": "RepositoryTagProtection"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryTopics",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryTopics:RepositoryTopics": "RepositoryTopics"
  }
 },
 {
  "pkg": "github",
  "mod": "index/repositoryWebhook",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/repositoryWebhook:RepositoryWebhook": "RepositoryWebhook"
  }
 },
 {
  "pkg": "github",
  "mod": "index/team",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/team:Team": "Team"
  }
 },
 {
  "pkg": "github",
  "mod": "index/teamMembers",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/teamMembers:TeamMembers": "TeamMembers"
  }
 },
 {
  "pkg": "github",
  "mod": "index/teamMembership",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/teamMembership:TeamMembership": "TeamMembership"
  }
 },
 {
  "pkg": "github",
  "mod": "index/teamRepository",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/teamRepository:TeamRepository": "TeamRepository"
  }
 },
 {
  "pkg": "github",
  "mod": "index/teamSettings",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/teamSettings:TeamSettings": "TeamSettings"
  }
 },
 {
  "pkg": "github",
  "mod": "index/teamSyncGroupMapping",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/teamSyncGroupMapping:TeamSyncGroupMapping": "TeamSyncGroupMapping"
  }
 },
 {
  "pkg": "github",
  "mod": "index/userGpgKey",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/userGpgKey:UserGpgKey": "UserGpgKey"
  }
 },
 {
  "pkg": "github",
  "mod": "index/userInvitationAccepter",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/userInvitationAccepter:UserInvitationAccepter": "UserInvitationAccepter"
  }
 },
 {
  "pkg": "github",
  "mod": "index/userSshKey",
  "fqn": "pulumi_github",
  "classes": {
   "github:index/userSshKey:UserSshKey": "UserSshKey"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "github",
  "token": "pulumi:providers:github",
  "fqn": "pulumi_github",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ActionsOrganizationOidcSubjectClaimCustomizationTemplateArgs', 'ActionsOrganizationOidcSubjectClaimCustomizationTemplate']

@pulumi.input_type
class ActionsOrganizationOidcSubjectClaimCustomizationTemplateArgs:
    def __init__(__self__, *,
                 include_claim_keys: pulumi.Input[Sequence[pulumi.Input[str]]]):
        """
        The set of arguments for constructing a ActionsOrganizationOidcSubjectClaimCustomizationTemplate resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] include_claim_keys: A list of OpenID Connect claims.
        """
        pulumi.set(__self__, "include_claim_keys", include_claim_keys)

    @property
    @pulumi.getter(name="includeClaimKeys")
    def include_claim_keys(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        A list of OpenID Connect claims.
        """
        return pulumi.get(self, "include_claim_keys")

    @include_claim_keys.setter
    def include_claim_keys(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "include_claim_keys", value)


@pulumi.input_type
class _ActionsOrganizationOidcSubjectClaimCustomizationTemplateState:
    def __init__(__self__, *,
                 include_claim_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ActionsOrganizationOidcSubjectClaimCustomizationTemplate resources.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] include_claim_keys: A list of OpenID Connect claims.
        """
        if include_claim_keys is not None:
            pulumi.set(__self__, "include_claim_keys", include_claim_keys)

    @property
    @pulumi.getter(name="includeClaimKeys")
    def include_claim_keys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of OpenID Connect claims.
        """
        return pulumi.get(self, "include_claim_keys")

    @include_claim_keys.setter
    def include_claim_keys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "include_claim_keys", value)


class ActionsOrganizationOidcSubjectClaimCustomizationTemplate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 include_claim_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        This resource allows you to create and manage an OpenID Connect subject claim customization template within a GitHub
        organization.

        More information on integrating GitHub with cloud providers using OpenID Connect and a list of available claims is
        available in the [Actions documentation](https://docs.github.com/en/actions/deployment/security-hardening-your-deployments/about-security-hardening-with-openid-connect).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        example_template = github.ActionsOrganizationOidcSubjectClaimCustomizationTemplate("example_template", include_claim_keys=[
            "actor",
            "context",
            "repository_owner",
        ])
        ```

        ## Import

        This resource can be imported using the organization's name.

        ```sh
        $ pulumi import github:index/actionsOrganizationOidcSubjectClaimCustomizationTemplate:ActionsOrganizationOidcSubjectClaimCustomizationTemplate test example_organization
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] include_claim_keys: A list of OpenID Connect claims.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ActionsOrganizationOidcSubjectClaimCustomizationTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and manage an OpenID Connect subject claim customization template within a GitHub
        organization.

        More information on integrating GitHub with cloud providers using OpenID Connect and a list of available claims is
        available in the [Actions documentation](https://docs.github.com/en/actions/deployment/security-hardening-your-deployments/about-security-hardening-with-openid-connect).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        example_template = github.ActionsOrganizationOidcSubjectClaimCustomizationTemplate("example_template", include_claim_keys=[
            "actor",
            "context",
            "repository_owner",
        ])
        ```

        ## Import

        This resource can be imported using the organization's name.

        ```sh
        $ pulumi import github:index/actionsOrganizationOidcSubjectClaimCustomizationTemplate:ActionsOrganizationOidcSubjectClaimCustomizationTemplate test example_organization
        ```

        :param str resource_name: The name of the resource.
        :param ActionsOrganizationOidcSubjectClaimCustomizationTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ActionsOrganizationOidcSubjectClaimCustomizationTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 include_claim_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ActionsOrganizationOidcSubjectClaimCustomizationTemplateArgs.__new__(ActionsOrganizationOidcSubjectClaimCustomizationTemplateArgs)

            if include_claim_keys is None and not opts.urn:
                raise TypeError("Missing required property 'include_claim_keys'")
            __props__.__dict__["include_claim_keys"] = include_claim_keys
        super(ActionsOrganizationOidcSubjectClaimCustomizationTemplate, __self__).__init__(
            'github:index/actionsOrganizationOidcSubjectClaimCustomizationTemplate:ActionsOrganizationOidcSubjectClaimCustomizationTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            include_claim_keys: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'ActionsOrganizationOidcSubjectClaimCustomizationTemplate':
        """
        Get an existing ActionsOrganizationOidcSubjectClaimCustomizationTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] include_claim_keys: A list of OpenID Connect claims.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ActionsOrganizationOidcSubjectClaimCustomizationTemplateState.__new__(_ActionsOrganizationOidcSubjectClaimCustomizationTemplateState)

        __props__.__dict__["include_claim_keys"] = include_claim_keys
        return ActionsOrganizationOidcSubjectClaimCustomizationTemplate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="includeClaimKeys")
    def include_claim_keys(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of OpenID Connect claims.
        """
        return pulumi.get(self, "include_claim_keys")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['EnterpriseActionsRunnerGroupArgs', 'EnterpriseActionsRunnerGroup']

@pulumi.input_type
class EnterpriseActionsRunnerGroupArgs:
    def __init__(__self__, *,
                 enterprise_slug: pulumi.Input[str],
                 visibility: pulumi.Input[str],
                 allows_public_repositories: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 restricted_to_workflows: Optional[pulumi.Input[bool]] = None,
                 selected_organization_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 selected_workflows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a EnterpriseActionsRunnerGroup resource.
        :param pulumi.Input[str] enterprise_slug: The slug of the enterprise.
        :param pulumi.Input[str] visibility: Visibility of a runner group to enterprise organizations. Whether the runner group can include `all` or `selected`
        :param pulumi.Input[bool] allows_public_repositories: Whether public repositories can be added to the runner group. Defaults to false.
        :param pulumi.Input[str] name: Name of the runner group
        :param pulumi.Input[bool] restricted_to_workflows: If true, the runner group will be restricted to running only the workflows specified in the selected_workflows array. Defaults to false.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] selected_organization_ids: IDs of the organizations which should be added to the runner group
        :param pulumi.Input[Sequence[pulumi.Input[str]]] selected_workflows: List of workflows the runner group should be allowed to run. This setting will be ignored unless restricted_to_workflows is set to true.
        """
        pulumi.set(__self__, "enterprise_slug", enterprise_slug)
        pulumi.set(__self__, "visibility", visibility)
        if allows_public_repositories is not None:
            pulumi.set(__self__, "allows_public_repositories", allows_public_repositories)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if restricted_to_workflows is not None:
            pulumi.set(__self__, "restricted_to_workflows", restricted_to_workflows)
        if selected_organization_ids is not None:
            pulumi.set(__self__, "selected_organization_ids", selected_organization_ids)
        if selected_workflows is not None:
            pulumi.set(__self__, "selected_workflows", selected_workflows)

    @property
    @pulumi.getter(name="enterpriseSlug")
    def enterprise_slug(self) -> pulumi.Input[str]:
        """
        The slug of the enterprise.
        """
        return pulumi.get(self, "enterprise_slug")

    @enterprise_slug.setter
    def enterprise_slug(self, value: pulumi.Input[str]):
        pulumi.set(self, "enterprise_slug", value)

    @property
    @pulumi.getter
    def visibility(self) -> pulumi.Input[str]:
        """
        Visibility of a runner group to enterprise organizations. Whether the runner group can include `all` or `selected`
        """
        return pulumi.get(self, "visibility")

    @visibility.setter
    def visibility(self, value: pulumi.Input[str]):
        pulumi.set(self, "visibility", value)

    @property
    @pulumi.getter(name="allowsPublicRepositories")
    def allows_public_repositories(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether public repositories can be added to the runner group. Defaults to false.
        """
        return pulumi.get(self, "allows_public_repositories")

    @allows_public_repositories.setter
    def allows_public_repositories(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allows_public_repositories", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the runner group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="restrictedToWorkflows")
    def restricted_to_workflows(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, the runner group will be restricted to running only the workflows specified in the selected_workflows array. Defaults to false.
        """
        return pulumi.get(self, "restricted_to_workflows")

    @restricted_to_workflows.setter
    def restricted_to_workflows(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "restricted_to_workflows", value)

    @property
    @pulumi.getter(name="selectedOrganizationIds")
    def selected_organization_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        IDs of the organizations which should be added to the runner group
        """
        return pulumi.get(self, "selected_organization_ids")

    @selected_organization_ids.setter
    def selected_organization_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "selected_organization_ids", value)

    @property
    @pulumi.getter(name="selectedWorkflows")
    def selected_workflows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of workflows the runner group should be allowed to run. This setting will be ignored unless restricted_to_workflows is set to true.
        """
        return pulumi.get(self, "selected_workflows")

    @selected_workflows.setter
    def selected_workflows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "selected_workflows", value)


@pulumi.input_type
class _EnterpriseActionsRunnerGroupState:
    def __init__(__self__, *,
                 allows_public_repositories: Optional[pulumi.Input[bool]] = None,
                 default: Optional[pulumi.Input[bool]] = None,
                 enterprise_slug: Optional[pulumi.Input[str]] = None,
                 etag: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 restricted_to_workflows: Optional[pulumi.Input[bool]] = None,
                 runners_url: Optional[pulumi.Input[str]] = None,
                 selected_organization_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 selected_organizations_url: Optional[pulumi.Input[str]] = None,
                 selected_workflows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 visibility: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EnterpriseActionsRunnerGroup resources.
        :param pulumi.Input[bool] allows_public_repositories: Whether public repositories can be added to the runner group. Defaults to false.
        :param pulumi.Input[bool] default: Whether this is the default runner group
        :param pulumi.Input[str] enterprise_slug: The slug of the enterprise.
        :param pulumi.Input[str] etag: An etag representing the runner group object
        :param pulumi.Input[str] name: Name of the runner group
        :param pulumi.Input[bool] restricted_to_workflows: If true, the runner group will be restricted to running only the workflows specified in the selected_workflows array. Defaults to false.
        :param pulumi.Input[str] runners_url: The GitHub API URL for the runner group's runners
        :param pulumi.Input[Sequence[pulumi.Input[int]]] selected_organization_ids: IDs of the organizations which should be added to the runner group
        :param pulumi.Input[str] selected_organizations_url: The GitHub API URL for the runner group's selected organizations
        :param pulumi.Input[Sequence[pulumi.Input[str]]] selected_workflows: List of workflows the runner group should be allowed to run. This setting will be ignored unless restricted_to_workflows is set to true.
        :param pulumi.Input[str] visibility: Visibility of a runner group to enterprise organizations. Whether the runner group can include `all` or `selected`
        """
        if allows_public_repositories is not None:
            pulumi.set(__self__, "allows_public_repositories", allows_public_repositories)
        if default is not None:
            pulumi.set(__self__, "default", default)
        if enterprise_slug is not None:
            pulumi.set(__self__, "enterprise_slug", enterprise_slug)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if restricted_to_workflows is not None:
            pulumi.set(__self__, "restricted_to_workflows", restricted_to_workflows)
        if runners_url is not None:
            pulumi.set(__self__, "runners_url", runners_url)
        if selected_organization_ids is not None:
            pulumi.set(__self__, "selected_organization_ids", selected_organization_ids)
        if selected_organizations_url is not None:
            pulumi.set(__self__, "selected_organizations_url", selected_organizations_url)
        if selected_workflows is not None:
            pulumi.set(__self__, "selected_workflows", selected_workflows)
        if visibility is not None:
            pulumi.set(__self__, "visibility", visibility)

    @property
    @pulumi.getter(name="allowsPublicRepositories")
    def allows_public_repositories(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether public repositories can be added to the runner group. Defaults to false.
        """
        return pulumi.get(self, "allows_public_repositories")

    @allows_public_repositories.setter
    def allows_public_repositories(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allows_public_repositories", value)

    @property
    @pulumi.getter
    def default(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether this is the default runner group
        """
        return pulumi.get(self, "default")

    @default.setter
    def default(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "default", value)

    @property
    @pulumi.getter(name="enterpriseSlug")
    def enterprise_slug(self) -> Optional[pulumi.Input[str]]:
        """
        The slug of the enterprise.
        """
        return pulumi.get(self, "enterprise_slug")

    @enterprise_slug.setter
    def enterprise_slug(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enterprise_slug", value)

    @property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[str]]:
        """
        An etag representing the runner group object
        """
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "etag", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the runner group
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="restrictedToWorkflows")
    def restricted_to_workflows(self) -> Optional[pulumi.Input[bool]]:
        """
        If true, the runner group will be restricted to running only the workflows specified in the selected_workflows array. Defaults to false.
        """
        return pulumi.get(self, "restricted_to_workflows")

    @restricted_to_workflows.setter
    def restricted_to_workflows(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "restricted_to_workflows", value)

    @property
    @pulumi.getter(name="runnersUrl")
    def runners_url(self) -> Optional[pulumi.Input[str]]:
        """
        The GitHub API URL for the runner group's runners
        """
        return pulumi.get(self, "runners_url")

    @runners_url.setter
    def runners_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "runners_url", value)

    @property
    @pulumi.getter(name="selectedOrganizationIds")
    def selected_organization_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        IDs of the organizations which should be added to the runner group
        """
        return pulumi.get(self, "selected_organization_ids")

    @selected_organization_ids.setter
    def selected_organization_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "selected_organization_ids", value)

    @property
    @pulumi.getter(name="selectedOrganizationsUrl")
    def selected_organizations_url(self) -> Optional[pulumi.Input[str]]:
        """
        The GitHub API URL for the runner group's selected organizations
        """
        return pulumi.get(self, "selected_organizations_url")

    @selected_organizations_url.setter
    def selected_organizations_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "selected_organizations_url", value)

    @property
    @pulumi.getter(name="selectedWorkflows")
    def selected_workflows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        List of workflows the runner group should be allowed to run. This setting will be ignored unless restricted_to_workflows is set to true.
        """
        return pulumi.get(self, "selected_workflows")

    @selected_workflows.setter
    def selected_workflows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "selected_workflows", value)

    @property
    @pulumi.getter
    def visibility(self) -> Optional[pulumi.Input[str]]:
        """
        Visibility of a runner group to enterprise organizations. Whether the runner group can include `all` or `selected`
        """
        return pulumi.get(self, "visibility")

    @visibility.setter
    def visibility(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "visibility", value)


class EnterpriseActionsRunnerGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allows_public_repositories: Optional[pulumi.Input[bool]] = None,
                 enterprise_slug: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 restricted_to_workflows: Optional[pulumi.Input[bool]] = None,
                 selected_organization_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 selected_workflows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 visibility: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource allows you to create and manage GitHub Actions runner groups within your GitHub enterprise.
        You must have admin access to an enterprise to use this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        enterprise = github.get_enterprise(slug="my-enterprise")
        enterprise_organization = github.EnterpriseOrganization("enterprise_organization",
            enterprise_id=enterprise.id,
            name="my-organization",
            billing_email="octocat@octo.cat",
            admin_logins=["octocat"])
        example = github.EnterpriseActionsRunnerGroup("example",
            name="my-awesome-runner-group",
            enterprise_slug=enterprise.slug,
            allows_public_repositories=True,
            visibility="selected",
            selected_organization_ids=[enterprise_organization.database_id],
            restricted_to_workflows=True,
            selected_workflows=["my-organization/my-repo/.github/workflows/cool-workflow.yaml@refs/tags/v1"])
        ```

        ## Import

        This resource can be imported using the enterprise slug and the ID of the runner group:

        ```sh
        $ pulumi import github:index/enterpriseActionsRunnerGroup:EnterpriseActionsRunnerGroup test enterprise-slug/42
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allows_public_repositories: Whether public repositories can be added to the runner group. Defaults to false.
        :param pulumi.Input[str] enterprise_slug: The slug of the enterprise.
        :param pulumi.Input[str] name: Name of the runner group
        :param pulumi.Input[bool] restricted_to_workflows: If true, the runner group will be restricted to running only the workflows specified in the selected_workflows array. Defaults to false.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] selected_organization_ids: IDs of the organizations which should be added to the runner group
        :param pulumi.Input[Sequence[pulumi.Input[str]]] selected_workflows: List of workflows the runner group should be allowed to run. This setting will be ignored unless restricted_to_workflows is set to true.
        :param pulumi.Input[str] visibility: Visibility of a runner group to enterprise organizations. Whether the runner group can include `all` or `selected`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnterpriseActionsRunnerGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and manage GitHub Actions runner groups within your GitHub enterprise.
        You must have admin access to an enterprise to use this resource.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        enterprise = github.get_enterprise(slug="my-enterprise")
        enterprise_organization = github.EnterpriseOrganization("enterprise_organization",
            enterprise_id=enterprise.id,
            name="my-organization",
            billing_email="octocat@octo.cat",
            admin_logins=["octocat"])
        example = github.EnterpriseActionsRunnerGroup("example",
            name="my-awesome-runner-group",
            enterprise_slug=enterprise.slug,
            allows_public_repositories=True,
            visibility="selected",
            selected_organization_ids=[enterprise_organization.database_id],
            restricted_to_workflows=True,
            selected_workflows=["my-organization/my-repo/.github/workflows/cool-workflow.yaml@refs/tags/v1"])
        ```

        ## Import

        This resource can be imported using the enterprise slug and the ID of the runner group:

        ```sh
        $ pulumi import github:index/enterpriseActionsRunnerGroup:EnterpriseActionsRunnerGroup test enterprise-slug/42
        ```

        :param str resource_name: The name of the resource.
        :param EnterpriseActionsRunnerGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnterpriseActionsRunnerGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allows_public_repositories: Optional[pulumi.Input[bool]] = None,
                 enterprise_slug: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 restricted_to_workflows: Optional[pulumi.Input[bool]] = None,
                 selected_organization_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 selected_workflows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 visibility: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnterpriseActionsRunnerGroupArgs.__new__(EnterpriseActionsRunnerGroupArgs)

            __props__.__dict__["allows_public_repositories"] = allows_public_repositories
            if enterprise_slug is None and not opts.urn:
                raise TypeError("Missing required property 'enterprise_slug'")
            __props__.__dict__["enterprise_slug"] = enterprise_slug
            __props__.__dict__["name"] = name
            __props__.__dict__["restricted_to_workflows"] = restricted_to_workflows
            __props__.__dict__["selected_organization_ids"] = selected_organization_ids
            __props__.__dict__["selected_workflows"] = selected_workflows
            if visibility is None and not opts.urn:
                raise TypeError("Missing required property 'visibility'")
            __props__.__dict__["visibility"] = visibility
            __props__.__dict__["default"] = None
            __props__.__dict__["etag"] = None
            __props__.__dict__["runners_url"] = None
            __props__.__dict__["selected_organizations_url"] = None
        super(EnterpriseActionsRunnerGroup, __self__).__init__(
            'github:index/enterpriseActionsRunnerGroup:EnterpriseActionsRunnerGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allows_public_repositories: Optional[pulumi.Input[bool]] = None,
            default: Optional[pulumi.Input[bool]] = None,
            enterprise_slug: Optional[pulumi.Input[str]] = None,
            etag: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            restricted_to_workflows: Optional[pulumi.Input[bool]] = None,
            runners_url: Optional[pulumi.Input[str]] = None,
            selected_organization_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            selected_organizations_url: Optional[pulumi.Input[str]] = None,
            selected_workflows: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            visibility: Optional[pulumi.Input[str]] = None) -> 'EnterpriseActionsRunnerGroup':
        """
        Get an existing EnterpriseActionsRunnerGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allows_public_repositories: Whether public repositories can be added to the runner group. Defaults to false.
        :param pulumi.Input[bool] default: Whether this is the default runner group
        :param pulumi.Input[str] enterprise_slug: The slug of the enterprise.
        :param pulumi.Input[str] etag: An etag representing the runner group object
        :param pulumi.Input[str] name: Name of the runner group
        :param pulumi.Input[bool] restricted_to_workflows: If true, the runner group will be restricted to running only the workflows specified in the selected_workflows array. Defaults to false.
        :param pulumi.Input[str] runners_url: The GitHub API URL for the runner group's runners
        :param pulumi.Input[Sequence[pulumi.Input[int]]] selected_organization_ids: IDs of the organizations which should be added to the runner group
        :param pulumi.Input[str] selected_organizations_url: The GitHub API URL for the runner group's selected organizations
        :param pulumi.Input[Sequence[pulumi.Input[str]]] selected_workflows: List of workflows the runner group should be allowed to run. This setting will be ignored unless restricted_to_workflows is set to true.
        :param pulumi.Input[str] visibility: Visibility of a runner group to enterprise organizations. Whether the runner group can include `all` or `selected`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EnterpriseActionsRunnerGroupState.__new__(_EnterpriseActionsRunnerGroupState)

        __props__.__dict__["allows_public_repositories"] = allows_public_repositories
        __props__.__dict__["default"] = default
        __props__.__dict__["enterprise_slug"] = enterprise_slug
        __props__.__dict__["etag"] = etag
        __props__.__dict__["name"] = name
        __props__.__dict__["restricted_to_workflows"] = restricted_to_workflows
        __props__.__dict__["runners_url"] = runners_url
        __props__.__dict__["selected_organization_ids"] = selected_organization_ids
        __props__.__dict__["selected_organizations_url"] = selected_organizations_url
        __props__.__dict__["selected_workflows"] = selected_workflows
        __props__.__dict__["visibility"] = visibility
        return EnterpriseActionsRunnerGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowsPublicRepositories")
    def allows_public_repositories(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether public repositories can be added to the runner group. Defaults to false.
        """
        return pulumi.get(self, "allows_public_repositories")

    @property
    @pulumi.getter
    def default(self) -> pulumi.Output[bool]:
        """
        Whether this is the default runner group
        """
        return pulumi.get(self, "default")

    @property
    @pulumi.getter(name="enterpriseSlug")
    def enterprise_slug(self) -> pulumi.Output[str]:
        """
        The slug of the enterprise.
        """
        return pulumi.get(self, "enterprise_slug")

    @property
    @pulumi.getter
    def etag(self) -> pulumi.Output[str]:
        """
        An etag representing the runner group object
        """
        return pulumi.get(self, "etag")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the runner group
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="restrictedToWorkflows")
    def restricted_to_workflows(self) -> pulumi.Output[Optional[bool]]:
        """
        If true, the runner group will be restricted to running only the workflows specified in the selected_workflows array. Defaults to false.
        """
        return pulumi.get(self, "restricted_to_workflows")

    @property
    @pulumi.getter(name="runnersUrl")
    def runners_url(self) -> pulumi.Output[str]:
        """
        The GitHub API URL for the runner group's runners
        """
        return pulumi.get(self, "runners_url")

    @property
    @pulumi.getter(name="selectedOrganizationIds")
    def selected_organization_ids(self) -> pulumi.Output[Optional[Sequence[int]]]:
        """
        IDs of the organizations which should be added to the runner group
        """
        return pulumi.get(self, "selected_organization_ids")

    @property
    @pulumi.getter(name="selectedOrganizationsUrl")
    def selected_organizations_url(self) -> pulumi.Output[str]:
        """
        The GitHub API URL for the runner group's selected organizations
        """
        return pulumi.get(self, "selected_organizations_url")

    @property
    @pulumi.getter(name="selectedWorkflows")
    def selected_workflows(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        List of workflows the runner group should be allowed to run. This setting will be ignored unless restricted_to_workflows is set to true.
        """
        return pulumi.get(self, "selected_workflows")

    @property
    @pulumi.getter
    def visibility(self) -> pulumi.Output[str]:
        """
        Visibility of a runner group to enterprise organizations. Whether the runner group can include `all` or `selected`
        """
        return pulumi.get(self, "visibility")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetEnterpriseResult',
    'AwaitableGetEnterpriseResult',
    'get_enterprise',
    'get_enterprise_output',
]

@pulumi.output_type
class GetEnterpriseResult:
    """
    A collection of values returned by getEnterprise.
    """
    def __init__(__self__, created_at=None, database_id=None, description=None, id=None, name=None, slug=None, url=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if database_id and not isinstance(database_id, int):
            raise TypeError("Expected argument 'database_id' to be a int")
        pulumi.set(__self__, "database_id", database_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if slug and not isinstance(slug, str):
            raise TypeError("Expected argument 'slug' to be a str")
        pulumi.set(__self__, "slug", slug)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        The time the enterprise was created.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> int:
        """
        The database ID of the enterprise.
        """
        return pulumi.get(self, "database_id")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the enterprise.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the enterprise.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def slug(self) -> str:
        """
        The URL slug identifying the enterprise.
        """
        return pulumi.get(self, "slug")

    @property
    @pulumi.getter
    def url(self) -> str:
        """
        The url for the enterprise.
        """
        return pulumi.get(self, "url")


class AwaitableGetEnterpriseResult(GetEnterpriseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnterpriseResult(
            created_at=self.created_at,
            database_id=self.database_id,
            description=self.description,
            id=self.id,
            name=self.name,
            slug=self.slug,
            url=self.url)


def get_enterprise(slug: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnterpriseResult:
    """
    Use this data source to retrieve basic information about a GitHub enterprise.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_enterprise(slug="example-co")
    ```


    :param str slug: The URL slug identifying the enterprise.
    """
    __args__ = dict()
    __args__['slug'] = slug
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getEnterprise:getEnterprise', __args__, opts=opts, typ=GetEnterpriseResult).value

    return AwaitableGetEnterpriseResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        database_id=pulumi.get(__ret__, 'database_id'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        slug=pulumi.get(__ret__, 'slug'),
        url=pulumi.get(__ret__, 'url'))


@_utilities.lift_output_func(get_enterprise)
def get_enterprise_output(slug: Optional[pulumi.Input[str]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnterpriseResult]:
    """
    Use this data source to retrieve basic information about a GitHub enterprise.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_enterprise(slug="example-co")
    ```


    :param str slug: The URL slug identifying the enterprise.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['RepositoryCollaboratorArgs', 'RepositoryCollaborator']

@pulumi.input_type
class RepositoryCollaboratorArgs:
    def __init__(__self__, *,
                 repository: pulumi.Input[str],
                 username: pulumi.Input[str],
                 permission: Optional[pulumi.Input[str]] = None,
                 permission_diff_suppression: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a RepositoryCollaborator resource.
        :param pulumi.Input[str] repository: The GitHub repository
               
               > Note: The owner of the repository can be passed as part of the repository name  e.g. `owner-org-name/repo-name`. If owner is not supplied as part of the repository name, it may also be supplied by setting the environment variable `GITHUB_OWNER`.
        :param pulumi.Input[str] username: The user to add to the repository as a collaborator.
        :param pulumi.Input[str] permission: The permission of the outside collaborator for the repository.
               Must be one of `pull`, `push`, `maintain`, `triage` or `admin` or the name of an existing [custom repository role](https://docs.github.com/en/enterprise-cloud@latest/organizations/managing-peoples-access-to-your-organization-with-roles/managing-custom-repository-roles-for-an-organization) within the organization for organization-owned repositories.
               Must be `push` for personal repositories. Defaults to `push`.
        :param pulumi.Input[bool] permission_diff_suppression: Suppress plan diffs for `triage` and `maintain`.  Defaults to `false`.
        """
        pulumi.set(__self__, "repository", repository)
        pulumi.set(__self__, "username", username)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)
        if permission_diff_suppression is not None:
            pulumi.set(__self__, "permission_diff_suppression", permission_diff_suppression)

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Input[str]:
        """
        The GitHub repository

        > Note: The owner of the repository can be passed as part of the repository name  e.g. `owner-org-name/repo-name`. If owner is not supplied as part of the repository name, it may also be supplied by setting the environment variable `GITHUB_OWNER`.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: pulumi.Input[str]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter
    def username(self) -> pulumi.Input[str]:
        """
        The user to add to the repository as a collaborator.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[str]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter
    def permission(self) -> Optional[pulumi.Input[str]]:
        """
        The permission of the outside collaborator for the repository.
        Must be one of `pull`, `push`, `maintain`, `triage` or `admin` or the name of an existing [custom repository role](https://docs.github.com/en/enterprise-cloud@latest/organizations/managing-peoples-access-to-your-organization-with-roles/managing-custom-repository-roles-for-an-organization) within the organization for organization-owned repositories.
        Must be `push` for personal repositories. Defaults to `push`.
        """
        return pulumi.get(self, "permission")

    @permission.setter
    def permission(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "permission", value)

    @property
    @pulumi.getter(name="permissionDiffSuppression")
    def permission_diff_suppression(self) -> Optional[pulumi.Input[bool]]:
        """
        Suppress plan diffs for `triage` and `maintain`.  Defaults to `false`.
        """
        return pulumi.get(self, "permission_diff_suppression")

    @permission_diff_suppression.setter
    def permission_diff_suppression(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "permission_diff_suppression", value)


@pulumi.input_type
class _RepositoryCollaboratorState:
    def __init__(__self__, *,
                 invitation_id: Optional[pulumi.Input[str]] = None,
                 permission: Optional[pulumi.Input[str]] = None,
                 permission_diff_suppression: Optional[pulumi.Input[bool]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RepositoryCollaborator resources.
        :param pulumi.Input[str] invitation_id: ID of the invitation to be used in `UserInvitationAccepter`
        :param pulumi.Input[str] permission: The permission of the outside collaborator for the repository.
               Must be one of `pull`, `push`, `maintain`, `triage` or `admin` or the name of an existing [custom repository role](https://docs.github.com/en/enterprise-cloud@latest/organizations/managing-peoples-access-to-your-organization-with-roles/managing-custom-repository-roles-for-an-organization) within the organization for organization-owned repositories.
               Must be `push` for personal repositories. Defaults to `push`.
        :param pulumi.Input[bool] permission_diff_suppression: Suppress plan diffs for `triage` and `maintain`.  Defaults to `false`.
        :param pulumi.Input[str] repository: The GitHub repository
               
               > Note: The owner of the repository can be passed as part of the repository name  e.g. `owner-org-name/repo-name`. If owner is not supplied as part of the repository name, it may also be supplied by setting the environment variable `GITHUB_OWNER`.
        :param pulumi.Input[str] username: The user to add to the repository as a collaborator.
        """
        if invitation_id is not None:
            pulumi.set(__self__, "invitation_id", invitation_id)
        if permission is not None:
            pulumi.set(__self__, "permission", permission)
        if permission_diff_suppression is not None:
            pulumi.set(__self__, "permission_diff_suppression", permission_diff_suppression)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="invitationId")
    def invitation_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the invitation to be used in `UserInvitationAccepter`
        """
        return pulumi.get(self, "invitation_id")

    @invitation_id.setter
    def invitation_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "invitation_id", value)

    @property
    @pulumi.getter
    def permission(self) -> Optional[pulumi.Input[str]]:
        """
        The permission of the outside collaborator for the repository.
        Must be one of `pull`, `push`, `maintain`, `triage` or `admin` or the name of an existing [custom repository role](https://docs.github.com/en/enterprise-cloud@latest/organizations/managing-peoples-access-to-your-organization-with-roles/managing-custom-repository-roles-for-an-organization) within the organization for organization-owned repositories.
        Must be `push` for personal repositories. Defaults to `push`.
        """
        return pulumi.get(self, "permission")

    @permission.setter
    def permission(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "permission", value)

    @property
    @pulumi.getter(name="permissionDiffSuppression")
    def permission_diff_suppression(self) -> Optional[pulumi.Input[bool]]:
        """
        Suppress plan diffs for `triage` and `maintain`.  Defaults to `false`.
        """
        return pulumi.get(self, "permission_diff_suppression")

    @permission_diff_suppression.setter
    def permission_diff_suppression(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "permission_diff_suppression", value)

    @property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[str]]:
        """
        The GitHub repository

        > Note: The owner of the repository can be passed as part of the repository name  e.g. `owner-org-name/repo-name`. If owner is not supplied as part of the repository name, it may also be supplied by setting the environment variable `GITHUB_OWNER`.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[str]]:
        """
        The user to add to the repository as a collaborator.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "username", value)


class RepositoryCollaborator(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 permission: Optional[pulumi.Input[str]] = None,
                 permission_diff_suppression: Optional[pulumi.Input[bool]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a GitHub repository collaborator resource.

        > Note: RepositoryCollaborator cannot be used in conjunction with RepositoryCollaborators or
        they will fight over what your policy should be.

        This resource allows you to add/remove collaborators from repositories in your
        organization or personal account. For organization repositories, collaborators can
        have explicit (and differing levels of) read, write, or administrator access to
        specific repositories, without giving the user full organization membership.
        For personal repositories, collaborators can only be granted write
        (implicitly includes read) permission.

        When applied, an invitation will be sent to the user to become a collaborator
        on a repository. When destroyed, either the invitation will be cancelled or the
        collaborator will be removed from the repository.

        This resource is non-authoritative, for managing ALL collaborators of a repo, use RepositoryCollaborators
        instead.

        Further documentation on GitHub collaborators:

        - [Adding outside collaborators to your personal repositories](https://help.github.com/en/github/setting-up-and-managing-your-github-user-account/managing-access-to-your-personal-repositories)
        - [Adding outside collaborators to repositories in your organization](https://help.github.com/articles/adding-outside-collaborators-to-repositories-in-your-organization/)
        - [Converting an organization member to an outside collaborator](https://help.github.com/articles/converting-an-organization-member-to-an-outside-collaborator/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        # Add a collaborator to a repository
        a_repo_collaborator = github.RepositoryCollaborator("a_repo_collaborator",
            repository="our-cool-repo",
            username="SomeUser",
            permission="admin")
        ```

        ## Import

        GitHub Repository Collaborators can be imported using an ID made up of `repository:username`, e.g.

        ```sh
        $ pulumi import github:index/repositoryCollaborator:RepositoryCollaborator collaborator terraform:someuser
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] permission: The permission of the outside collaborator for the repository.
               Must be one of `pull`, `push`, `maintain`, `triage` or `admin` or the name of an existing [custom repository role](https://docs.github.com/en/enterprise-cloud@latest/organizations/managing-peoples-access-to-your-organization-with-roles/managing-custom-repository-roles-for-an-organization) within the organization for organization-owned repositories.
               Must be `push` for personal repositories. Defaults to `push`.
        :param pulumi.Input[bool] permission_diff_suppression: Suppress plan diffs for `triage` and `maintain`.  Defaults to `false`.
        :param pulumi.Input[str] repository: The GitHub repository
               
               > Note: The owner of the repository can be passed as part of the repository name  e.g. `owner-org-name/repo-name`. If owner is not supplied as part of the repository name, it may also be supplied by setting the environment variable `GITHUB_OWNER`.
        :param pulumi.Input[str] username: The user to add to the repository as a collaborator.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepositoryCollaboratorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a GitHub repository collaborator resource.

        > Note: RepositoryCollaborator cannot be used in conjunction with RepositoryCollaborators or
        they will fight over what your policy should be.

        This resource allows you to add/remove collaborators from repositories in your
        organization or personal account. For organization repositories, collaborators can
        have explicit (and differing levels of) read, write, or administrator access to
        specific repositories, without giving the user full organization membership.
        For personal repositories, collaborators can only be granted write
        (implicitly includes read) permission.

        When applied, an invitation will be sent to the user to become a collaborator
        on a repository. When destroyed, either the invitation will be cancelled or the
        collaborator will be removed from the repository.

        This resource is non-authoritative, for managing ALL collaborators of a repo, use RepositoryCollaborators
        instead.

        Further documentation on GitHub collaborators:

        - [Adding outside collaborators to your personal repositories](https://help.github.com/en/github/setting-up-and-managing-your-github-user-account/managing-access-to-your-personal-repositories)
        - [Adding outside collaborators to repositories in your organization](https://help.github.com/articles/adding-outside-collaborators-to-repositories-in-your-organization/)
        - [Converting an organization member to an outside collaborator](https://help.github.com/articles/converting-an-organization-member-to-an-outside-collaborator/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        # Add a collaborator to a repository
        a_repo_collaborator = github.RepositoryCollaborator("a_repo_collaborator",
            repository="our-cool-repo",
            username="SomeUser",
            permission="admin")
        ```

        ## Import

        GitHub Repository Collaborators can be imported using an ID made up of `repository:username`, e.g.

        ```sh
        $ pulumi import github:index/repositoryCollaborator:RepositoryCollaborator collaborator terraform:someuser
        ```

        :param str resource_name: The name of the resource.
        :param RepositoryCollaboratorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepositoryCollaboratorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 permission: Optional[pulumi.Input[str]] = None,
                 permission_diff_suppression: Optional[pulumi.Input[bool]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 username: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepositoryCollaboratorArgs.__new__(RepositoryCollaboratorArgs)

            __props__.__dict__["permission"] = permission
            __props__.__dict__["permission_diff_suppression"] = permission_diff_suppression
            if repository is None and not opts.urn:
                raise TypeError("Missing required property 'repository'")
            __props__.__dict__["repository"] = repository
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
            __props__.__dict__["invitation_id"] = None
        super(RepositoryCollaborator, __self__).__init__(
            'github:index/repositoryCollaborator:RepositoryCollaborator',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            invitation_id: Optional[pulumi.Input[str]] = None,
            permission: Optional[pulumi.Input[str]] = None,
            permission_diff_suppression: Optional[pulumi.Input[bool]] = None,
            repository: Optional[pulumi.Input[str]] = None,
            username: Optional[pulumi.Input[str]] = None) -> 'RepositoryCollaborator':
        """
        Get an existing RepositoryCollaborator resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] invitation_id: ID of the invitation to be used in `UserInvitationAccepter`
        :param pulumi.Input[str] permission: The permission of the outside collaborator for the repository.
               Must be one of `pull`, `push`, `maintain`, `triage` or `admin` or the name of an existing [custom repository role](https://docs.github.com/en/enterprise-cloud@latest/organizations/managing-peoples-access-to-your-organization-with-roles/managing-custom-repository-roles-for-an-organization) within the organization for organization-owned repositories.
               Must be `push` for personal repositories. Defaults to `push`.
        :param pulumi.Input[bool] permission_diff_suppression: Suppress plan diffs for `triage` and `maintain`.  Defaults to `false`.
        :param pulumi.Input[str] repository: The GitHub repository
               
               > Note: The owner of the repository can be passed as part of the repository name  e.g. `owner-org-name/repo-name`. If owner is not supplied as part of the repository name, it may also be supplied by setting the environment variable `GITHUB_OWNER`.
        :param pulumi.Input[str] username: The user to add to the repository as a collaborator.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepositoryCollaboratorState.__new__(_RepositoryCollaboratorState)

        __props__.__dict__["invitation_id"] = invitation_id
        __props__.__dict__["permission"] = permission
        __props__.__dict__["permission_diff_suppression"] = permission_diff_suppression
        __props__.__dict__["repository"] = repository
        __props__.__dict__["username"] = username
        return RepositoryCollaborator(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="invitationId")
    def invitation_id(self) -> pulumi.Output[str]:
        """
        ID of the invitation to be used in `UserInvitationAccepter`
        """
        return pulumi.get(self, "invitation_id")

    @property
    @pulumi.getter
    def permission(self) -> pulumi.Output[Optional[str]]:
        """
        The permission of the outside collaborator for the repository.
        Must be one of `pull`, `push`, `maintain`, `triage` or `admin` or the name of an existing [custom repository role](https://docs.github.com/en/enterprise-cloud@latest/organizations/managing-peoples-access-to-your-organization-with-roles/managing-custom-repository-roles-for-an-organization) within the organization for organization-owned repositories.
        Must be `push` for personal repositories. Defaults to `push`.
        """
        return pulumi.get(self, "permission")

    @property
    @pulumi.getter(name="permissionDiffSuppression")
    def permission_diff_suppression(self) -> pulumi.Output[Optional[bool]]:
        """
        Suppress plan diffs for `triage` and `maintain`.  Defaults to `false`.
        """
        return pulumi.get(self, "permission_diff_suppression")

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Output[str]:
        """
        The GitHub repository

        > Note: The owner of the repository can be passed as part of the repository name  e.g. `owner-org-name/repo-name`. If owner is not supplied as part of the repository name, it may also be supplied by setting the environment variable `GITHUB_OWNER`.
        """
        return pulumi.get(self, "repository")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[str]:
        """
        The user to add to the repository as a collaborator.
        """
        return pulumi.get(self, "username")

